bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDToGaussianWishart.plates
=============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoattribute:: GaussianGammaARDToGaussianWishart.plates